@@ -19,6 +19,16 @@ from cherrypy.lib.encoding import compress, decompress
 rpcmethod = rpclib.rpcmethod
 
 
+
+def _no_body_processor_tool():
+    if cherrypy.request.method == "POST":
+        cherrypy.request.body.processors = {}
+
+cherrypy.tools.no_body_processor = cherrypy.Tool(
+    "on_start_resource", _no_body_processor_tool
+)
+
+
 class CherryPyJsonRpc(rpclib.JsonRpc):
     """
     CherryPy JSON-RPC
@@ -26,6 +36,7 @@ class CherryPyJsonRpc(rpclib.JsonRpc):
 
     @cherrypy.expose
     @cherrypy.tools.encode(encoding = "utf-8")
+    @cherrypy.tools.no_body_processor()
     def request_handler(self, *args, **kwargs):
         """
         Json-RPC Handler
@@ -34,21 +45,11 @@ class CherryPyJsonRpc(rpclib.JsonRpc):
         if cherrypy.request.method == "GET":
             # GET
 
-            # jsonrpc
+            # Arguments
             jsonrpc = kwargs.get("jsonrpc")
-            if jsonrpc:
-                jsonrpc = jsonrpc[0]
-
-            # id
             id = kwargs.get("id")
-            if id:
-                id = id[0]
-
-            # method
             method = kwargs.get("method")
-            if method:
-                method = method[0]
-            else:
+            if not method:
                 # Bad Request
                 raise cherrypy.HTTPError(httplib.BAD_REQUEST)
 
@@ -57,7 +58,7 @@ class CherryPyJsonRpc(rpclib.JsonRpc):
             _kwargs = {}
             params = kwargs.get("params")
             if params:
-                params = rpcjson.loads(params[0])
+                params = rpcjson.loads(params)
                 if isinstance(params, list):
                     _args = params
                     _kwargs = {}
